@@ -9,16 +9,16 @@ from .core import load_text, load_json, load_npy, load_pkl
 from .core import request_text_experimental, request_json_experimental, request_npy_experimental, request_pkl_experimental
 from .core import store_text_local, store_json_local, store_npy_local, store_pkl_local
 from .load_bytes import load_bytes
-from .get_kachery_cloud_dir import get_kachery_cloud_dir
+from .get_kachery_cloud_dir import get_kachery_cloud_dir, use_sandbox
 from .init import init
 from .feeds.create_feed import create_feed
 from .feeds.load_feed import load_feed
 from .feeds.Feed import Feed
 from .get_client_id import get_client_id
 from .get_project_id import get_project_id
-from .mutable import get_mutable, set_mutable
-from .mutable_local import get_mutable_local, set_mutable_local
+from .mutable import delete_mutable, delete_mutable_folder, get_mutable, set_mutable
+from .mutable_local import delete_mutable_folder_local, delete_mutable_local, get_mutable_local, set_mutable_local
 from .TemporaryDirectory import TemporaryDirectory
 from ._sha1_of_dict import sha1_of_dict
 from .encrypt_uri import encrypt_uri, decrypt_uri
-from .share_local_files_experimental import share_local_files_experimental
\ No newline at end of file
+from .share_local_files_experimental import share_local_files_experimental
