@@ -1,8 +1,10 @@
+from hashlib import sha1
 import os
 import shutil
 import requests
 from typing import Union
 from urllib.parse import quote
+import time
 
 from .get_kachery_cloud_dir import get_kachery_cloud_dir
 
@@ -10,9 +12,11 @@ from ._kacherycloud_request import _kacherycloud_request
 from .get_project_id import get_project_id
 from .load_file import _random_string
 from ._fs_operations import _makedirs, _chmod_file
-from .store_file_local import _compute_file_hash
+from .store_file_local import _compute_file_hash, store_file_local
 
-def store_file(filename: str, *, label: Union[str, None]=None, cache_locally: bool=False):
+def store_file(filename: str, *, label: Union[str, None]=None, cache_locally: bool=False, local: bool=False):
+    if local:
+        return store_file_local(filename, label=label)
     size = os.path.getsize(filename)
     alg = 'sha1'
     hash0 = _compute_file_hash(filename, algorithm=alg)
@@ -24,12 +28,24 @@ def store_file(filename: str, *, label: Union[str, None]=None, cache_locally: bo
         'hash': hash0,
         'projectId': get_project_id()
     }
-    response = _kacherycloud_request(payload)
-    already_exists = response['alreadyExists']
-    if already_exists:
-        if label is not None:
-            uri = f'{uri}?label={quote(label)}'
-        return uri
+    timer = time.time()
+    while True:
+        response: dict = _kacherycloud_request(payload)
+        already_exists = response.get('alreadyExists', False)
+        already_pending = response.get('alreadyPending', False)
+        if already_exists:
+            if label is not None:
+                uri = f'{uri}?label={quote(label)}'
+            return uri
+        elif already_pending:
+            elapsed = time.time() - timer
+            if elapsed > 60:
+                raise Exception(f'Upload is already pending... timeout: {uri}')
+            print(f'Upload is already pending... waiting to retry {uri}')
+            time.sleep(5)
+        else:
+            break
+        
     signed_upload_url = response['signedUploadUrl']
     object_key = response['objectKey']
     with open(filename, 'rb') as f:
@@ -58,7 +74,7 @@ def store_file(filename: str, *, label: Union[str, None]=None, cache_locally: bo
             shutil.copyfile(filename, tmp_filename)
             try:
                 os.rename(tmp_filename, filename)
-                _chmod_file(filename)
+                # _chmod_file(filename)
             except:
                 if not os.path.exists(cache_filename):
                     raise Exception(f'Problem renaming file: {tmp_filename} {filename}')
